#!/bin/bash

# setup the environment prior to installation
export DEBIAN_FRONTEND=noninteractive
sudo debconf-set-selections <<EOF
mysql-server-5.1 mysql-server/root_password password ubuntu
mysql-server-5.1 mysql-server/root_password_again password ubuntu
bacula-director-mysql bacula-director-mysql/dbconfig-install boolean true
bacula-director-mysql bacula-director-mysql/mysql/app-pass password bacula
bacula-director-mysql bacula-director-mysql/mysql/admin-pass password ubuntu
bacula-director-mysql bacula-director-mysql/app-password-confirm password bacula
EOF

# Preinstall MySQL
sudo apt-get -q -y install mysql-server

# Install Bacula components
sudo apt-get -q -y install bacula-director-mysql bacula-sd bacula-fd bacula-console

# Get hostname 
HOSTNAME=`hostname`

# Collect default passwords
. /etc/bacula/common_default_passwords

# Configure bacula-sd
[ -d /srv ] || mkdir /srv
[ -f /srv/backup ] || touch /srv/backup
chown -Rf bacula:bacula /srv
cat > /etc/bacula/bacula-sd.conf << EOF
Storage {
  Name = ${HOSTNAME}-sd
  SDPort = 9103
  WorkingDirectory = "/var/lib/bacula"
  Pid Directory = "/var/run/bacula"
  Maximum Concurrent Jobs = 20
}

Director {
  Name = ${HOSTNAME}-dir
  Password = "${SDPASSWD}"
}

Director {
  Name = ${HOSTNAME}-mon
  Password = "${SDMPASSWD}"
  Monitor = yes
}

Device {
  Name = testdevice
  Media Type = File
  Archive Device = /srv/backup
  LabelMedia = yes
  Random Access = yes
  AutomaticMount = yes
  RemovableMedia = no
  AlwaysOpen = no
}

Messages {
  Name = Standard
  director = ${HOSTNAME}-dir = all
}
EOF
service bacula-sd restart

# Configure bacula-fd
cat > /etc/bacula/bacula-fd.conf << EOF
Director {
  Name = ${HOSTNAME}-dir
  Password = "${FDPASSWD}"
}

Director {
  Name = ${HOSTNAME}-mon
  Password = "${FDMPASSWD}"
  Monitor = yes
}

FileDaemon {
  Name = ${HOSTNAME}-fd
  FDport = 9102
  WorkingDirectory = /var/lib/bacula
  Pid Directory = /var/run/bacula
  Maximum Concurrent Jobs = 20
  FDAddress = ${HOSTNAME}
}

Messages {
  Name = Standard
  director = ${HOSTNAME}-dir = all, !skipped, !restored
}
EOF
service bacula-fd restart

# Configure bacula-director
cat > /etc/bacula/bacula-dir.conf << EOF
Director {
  Name = ${HOSTNAME}-dir
  DIRport = 9101
  QueryFile = "/etc/bacula/scripts/query.sql"
  WorkingDirectory = "/var/lib/bacula"
  PidDirectory = "/var/run/bacula"
  Maximum Concurrent Jobs = 1
  Password = "consolePaSsWoRd"
  Messages = Daemon
  DirAddress = ${HOSTNAME}
}

JobDefs {
  Name = "Catalog"
  Type = Backup
  Level = Full
  Schedule = "DefaultSchedule"
  Storage = File
  Messages = Standard
  Pool = Default
}

Job {
  Name = "Catalog"
  JobDefs = "Catalog"
  Client = ${HOSTNAME}-fd
  FileSet = "CatalogSet"
  Schedule = "CatalogSchedule"
  RunBeforeJob = "/usr/bin/awk -f /etc/bacula/scripts/make_catalog_backup_awk -v cat1=MyCatalog /etc/bacula/bacula-dir.conf"
  RunAfterJob  = "/etc/bacula/scripts/delete_catalog_backup"
  Write Bootstrap = "/var/lib/bacula/BackupCatalog.bsr"
  Priority = 20
  Maximum Concurrent Jobs = 1
}

Job {
  Name = "Restore"
  Type = Restore
  Client = ${HOSTNAME}-fd
  FileSet = "SrvSet"
  Storage = File
  Pool = Default
  Messages = Standard
  Where = /tmp/bacula-restores
}

Schedule {
  Name = "DefaultSchedule"
  Run = Full sun at 01:00
  Run = Incremental mon-sat at 01:00
}

Schedule {
  Name = "CatalogSchedule"
  Run = Full sun at 12:00
  Run = Incremental mon-sat at 12:00
}

FileSet {
  Name = "CatalogSet"
  Include {
    Options {
      signature = MD5
      compression = gzip
    }
    File = /var/lib/bacula/bacula.sql
  }
}

FileSet {
  Name = "SrvSet"
  Include {
    Options {
      signature = MD5
      compression = gzip
    }
    File = /srv
  }
}

Client {
  Name = ${HOSTNAME}-fd
  Address = ${HOSTNAME}
  FDPort = 9102
  Catalog = MyCatalog
  Password = "${FDPASSWD}"
  File Retention = 30 days
  Job Retention = 25 days
  AutoPrune = yes
  Maximum Concurrent Jobs = 1
}

Storage {
  Name = File
  Address = ${HOSTNAME}
  SDPort = 9103
  Password = "${SDPASSWD}"
  Device = testdevice
  Media Type = File
  Maximum Concurrent Jobs = 3
}

Catalog {
  Name = MyCatalog
  dbname = bacula; DB Address = "localhost"; user = bacula; password = "bacula"
}

Messages {
  Name = Standard
  mailcommand = "/usr/lib/bacula/bsmtp -h localhost -f \"\(Bacula\) \<%r\>\" -s \"Bacula: %t %e of %c %l\" %r"
  operatorcommand = "/usr/lib/bacula/bsmtp -h localhost -f \"\(Bacula\) \<%r\>\" -s \"Bacula: Intervention needed for %j\" %r"
  mail = root@localhost = all, !skipped
  operator = root@localhost = mount
  console = all, !skipped, !saved
  append = "/var/lib/bacula/log" = all, !skipped
  catalog = all
}

Messages {
  Name = Daemon
  mailcommand = "/usr/lib/bacula/bsmtp -h localhost -f \"\(Bacula\) \<%r\>\" -s \"Bacula daemon message\" %r"
  mail = root@localhost = all, !skipped
  console = all, !skipped, !saved
  append = "/var/lib/bacula/log" = all, !skipped
}

Pool {
  Name = Default
  Pool Type = Backup
  Recycle = yes
  AutoPrune = yes
  Volume Retention = 365 days
  Maximum Volume Bytes = 5G
  Maximum Volumes = 100
  LabelFormat = "Vol-"
}

Console {
  Name = ${HOSTNAME}-mon
  Password = "${DIRMPASSWD}"
  CommandACL = status, .status
}
EOF
service bacula-director restart

# Configure bconsole
cat > /etc/bacula/bconsole.conf << EOF
Director {
  Name = localhost-dir
  DIRport = 9101
  address = ${HOSTNAME}
  Password = "consolePaSsWoRd"
}
EOF

#Initial Catalog backup
echo "run job=Catalog yes" | bconsole

#wait for log, then output results
while [ ! -s /var/log/bacula/log ] ; do 
    sleep 5
done

echo "Information from /var/log/bacula/log"
grep "  Elapsed time:" /var/log/bacula/log
grep "  FD Files Written:" /var/log/bacula/log
grep "  SD Files Written:" /var/log/bacula/log
grep "  FD Bytes Written:" /var/log/bacula/log
grep "  SD Bytes Written:" /var/log/bacula/log
grep "  Rate:" /var/log/bacula/log
