#!/bin/sh

set -e

MACHINES="../../scripts/machine_client.py"

#-- build up the environment needed
#
# Machines required:
#   bob (don't care about spec)
#   alice (don't care about spec)
bob=$($MACHINES GET)
alice=$($MACHINES GET)

#-- install packages needed
scp subtest-bob-setup.sh jenkins@$bob:~
ssh $bob \~/subtest-bob-setup.sh

scp subtest-alice-setup.sh jenkins@$alice:~
ssh $alice \~/subtest-alice-setup.sh

#-- install the scripts needed to run the workload
scp subtest-bob.sh jenkins@$bob:~
scp subtest-alice.sh jenkins@$alice:~

#-- run the "workload"
ssh $bob \~/subtest-bob.sh
ssh $alice \~/subtest-alice.sh $bob

output=$(ssh $bob cat /tmp/output)
result=$?
if [ "$result" = 0 ] && [ "$output" = "Hello, world!" ]; then
    echo PASS
    result=0
else
    echo FAIL
    result=1
fi

#-- release the machines used
$MACHINES PUT $bob
$MACHINES PUT $alice

#-- purge packages used
scp subtest-bob-cleanup.sh jenkins@$bob:~
ssh $bob \~/subtest-bob-cleanup.sh
scp subtest-alice-cleanup.sh jenkins@$alice:~
ssh $alice \~/subtest-alice-cleanup.sh

exit $result

