#!/bin/sh
set -e

# This script is passed the following environment variables:
#   TEST_TYPE: smoke or test. This should be set by the job that runs the
#              test runner.
#   SERVERS:   should contain a space-separated list of two servers to
#              run the ping test between. This is a machine class defined in
#              run_interface.yaml. You can set two servers up with ssh, set
#              the variable and run the test manually, or you can point the
#              test runner at run_interface.yaml and it will provision the
#              machines for you, set the variable and then run this script.

get_host_ip() {
    ssh $1 ip addr show primary dev eth0|sed -n 's!^\s*inet \(.*\)\/.*$!\1!p'
}

case $TEST_TYPE in
    smoke) ping_count_arg=-c1 ;;
    full) ping_count_arg=-c16 ;;
    *) echo "Error: no test type specified" >&2; exit 1 ;;
esac

# Is there a better way to do this in shell?
server1_name=`echo $SERVERS|cut -d\  -f1`
server2_name=`echo $SERVERS|cut -d\  -f2`

server2_ip=`get_host_ip $server1_name`
ssh $server1_name ping $ping_count_arg $server2_ip
