#!/bin/sh
set -e
MACHINES="../scripts/machine_client.py"
result=0

#-- set up the machine to act as a very small mail server
mailer=$($MACHINES GET)
scp mailer-setup.sh jenkins@$mailer:~
scp 10-auth.conf jenkins@$mailer:~
scp newusers.list jenkins@$mailer:~/newusers.list
ssh $mailer \~/mailer-setup.sh

#-- set up the machine to send mail to the server
postal=$($MACHINES GET)
cat newusers.list | cut -d: -f1 > /tmp/$$
scp /tmp/$$ jenkins@$postal:~/postal.list
rm -f /tmp/$$
scp postal-setup.sh jenkins@$postal:~
ssh $postal \~/postal-setup.sh

##-- set up the machine to POP mail from the server
rabid=$($MACHINES GET)
cat newusers.list | cut -d: -f1 | sed 's/.*/& iforgot/' > /tmp/$$
scp /tmp/$$ jenkins@$rabid:~/rabid.list
rm -f /tmp/$$
scp rabid-setup.sh jenkins@$rabid:~
ssh $rabid \~/rabid-setup.sh

#-- run a test and wait for things to complete
scp postal-run.sh jenkins@$postal:~
scp rabid-run.sh jenkins@$rabid:~
ssh $postal \~/postal-run.sh $mailer 3600 > ~/postal.out 2>&1 &
sleep 2
ssh $rabid \~/rabid-run.sh $mailer 3600 > ~/rabid.out 2>&1 &
wait %1 %2

#-- look for errors in the output
perr=$(grep -i error: ~/postal.out | head -1)
cnt=$(tail ~/postal.out | cut -d, -f4)
if [ "$cnt" != "0" ]; then
   perr="${perr}1"
fi
echo "I: postal reports $cnt errors"

rerr=$(grep -i error: ~/rabid.out | head -1)
cnt=$(grep 'MD5 mis-match' | wc -l)
if [ "$cnt" != "0" ]; then
   rerr="${rerr}1"
fi
echo "I: rabid reports $cnt MD5 mismatches"

if [ "${perr}${rerr}" ]; then
	echo FAIL
	result=1
else
	echo PASS
	result=0
fi

echo
echo "===================== postal.out ==============================="
cat ~/postal.out
echo "================================================================"

echo
echo "===================== rabid.out ==============================="
cat ~/rabid.out
echo "================================================================"
echo

#-- clean up the mail generator
scp postal-cleanup.sh jenkins@$postal:~
ssh $postal \~/postal-cleanup.sh
$MACHINES PUT $postal

#-- clean up the mail reader
scp rabid-cleanup.sh jenkins@$rabid:~
ssh $rabid \~/rabid-cleanup.sh
$MACHINES PUT $rabid

#-- clean up the mail server
scp mailer-cleanup.sh jenkins@$mailer:~
head -10 newusers.list > /tmp/$$
scp /tmp/$$ jenkins@$mailer:~/newusers.list
ssh $mailer \~/mailer-cleanup.sh
$MACHINES PUT $mailer

exit $result

