#! /usr/bin/python -B

import logging
from helpers import run, install, remove

class Memcached:
    def __init__(self, servers=None):
        self.servers = servers
        
    def setup(self):
        logging.debug("Begin Memcached:setup")
        logging.info("Setting up memcached")
        install("memcached", self.servers)
        run("sudo sed -e 's/-l 127.0.0.1//' -i /etc/memcached.conf && " + \
            "sudo /etc/init.d/memcached restart", self.servers)
        logging.debug("End Memcached:setup")
        
    def clean(self):
        logging.debug("Begin Memcached:clean")
        remove("memcached", self.servers)
        logging.debug("End Memcached:clean")

def main(argv=None):
    from optparse import OptionParser, make_option

    usage = "Usage: %prog [options] <server> <server...n>"
    epilog = "If no arguments are given, memcached will be setup on localhost. " + \
            "The <server> arguments are machines where memcached will be installed."
    option_list = [
        make_option("-l", "--log-level", default="info", dest="log_level",
                    choices=["debug", "info", "warning", "error", "critical"],
                    help="[ debug | *info | warning | error | critical ]"),
        make_option("--clean", action="store_true", dest="clean",
                    help="reverts changes made by the test"),
        make_option("--setup", action="store_true", dest="setup",
                    help="install and configure hadoop"),
    ]
    parser = OptionParser(usage=usage, epilog=epilog, option_list=option_list)
    (options, args) = parser.parse_args()
    
    logging.basicConfig(format='%(asctime)s %(levelname)s:%(message)s',
                        level=options.log_level.upper())

    if not options.clean and not options.setup:
        parser.error("Requires an argument, run with -h to see " \
                     "available arguments")

    memcached = Memcached(args)
    if options.setup:
        memcached.setup()
    
    if options.clean:
        memcached.clean()

if __name__ == "__main__":
    import sys, atexit

    atexit.register(logging.shutdown)
    sys.exit(main(sys.argv[1:]))

