#! /usr/bin/python -B

import logging
from helpers import run, install, remove

class Memcslap:
    def __init__(self, clients=None):
        self.clients = clients

    def setup(self):
        logging.debug("Begin Memcslap:setup")
        logging.info("Setting up memcslap")
        install("libmemcached-tools", self.clients)
        logging.debug("End Memcslap:setup")

    def clean(self):
        logging.debug("Begin Memcslap:clean")
        remove("libmemcached-tools libmemcached6", self.clients)
        logging.debug("End Memcslap:clean")

    def run_test(self, test_args=""):
        logging.info("Begin Memcslap:run_test: %s" % test_args)
        run("memcslap " + test_args, self.clients, print_to_console=True)
        logging.info("End Memcslap:run_test: %s" % test_args)

def main(argv=None):
    from optparse import OptionParser, make_option

    usage = "Usage: %prog [options] <client> <client...n>"
    epilog = "The <client> arguments specify where to install and " + \
            "run memcslap from."
    option_list = [
        make_option("-l", "--log-level", default="info", dest="log_level",
                    choices=["debug", "info", "warning", "error", "critical"],
                    help="[ debug | *info | warning | error | critical ]"),
        make_option("--clean", action="store_true", dest="clean",
                    help="reverts changes made by the test"),
        make_option("--setup", action="store_true", dest="setup",
                    help="install and configure hadoop"),
        make_option("-a", "--test-args", dest="test_args",
                    metavar="\"<args>\"",
                    help="test arguments"),
    ]
    parser = OptionParser(usage=usage, epilog=epilog, option_list=option_list)
    (options, args) = parser.parse_args()

    logging.basicConfig(format='%(asctime)s %(levelname)s:%(message)s',
    level=options.log_level.upper())

    if not options.clean and not options.setup and not options.test_args:
        parser.error("Requires an argument, run with -h to see " \
                     "available arguments")

    memcslap = Memcslap(args)
    if options.setup:
        memcslap.setup()

    if options.test_args:
        memcslap.run_test(options.test_args)

    if options.clean:
        memcslap.clean()

if __name__ == "__main__":
    import sys, atexit

    atexit.register(logging.shutdown)
    sys.exit(main(sys.argv[1:]))

