#! /bin/bash
set -e

get_host_ip() {
    ssh $1 ip addr show primary dev eth0|sed -n 's!^\s*inet \(.*\)\/.*$!\1!p'
}

get_hosts_ips() {
    for host in $@; do
        echo `get_host_ip $host`
    done
}

# Possible sub-tests are facebook and replication, plus we could also
# adjust the number of threads and concurrent calls to push one limit or
# another.
case $TEST_TYPE in
    smoke)
        test_args="-t 15s"
        ;;
    panda)
        threads=$((`echo ${SERVERS} | wc -w` * 2))
        concurrency=$((threads * 6))
        test_args="-T $threads -c $concurrency"
        ;;
    armadaxp)
        threads=$((`echo ${SERVERS} | wc -w` * 4))
        concurrency=$((threads * 4))
        test_args="-T $threads -c $concurrency"
        ;;
    *) echo "Error: no test type specified" >&2; exit 1 ;;
esac

if [ -n "${SERVERS}" ]; then
    server_ips=$(get_hosts_ips ${SERVERS})
    test_args="-s `echo ${server_ips} | tr ' ' ','` $test_args"
else
    test_args="-s 127.0.0.1 $test_args"
fi

$PWD/memcached.py --setup ${SERVERS}
$PWD/memcslap.py --setup -a "${test_args}" ${CLIENTS}

