#!/bin/sh
#
#	initial set up for keystone
#
#

set -e
#set -x

. ./envvars.sh

KEYVARS=keystone_envvars.sh
LOCAL_USER="'$KEYSTONE_DB_USER'@'localhost'"
REMOTE_USER="'$KEYSTONE_DB_USER'@'%'"
PASS="'$KEYSTONE_DB_PASS'"

#-- kill the old keystone DB
mysql -f -u $MYSQL_ADMIN -p$MYSQL_PASS <<EOF
DROP DATABASE $KEYSTONE_DB;
DROP USER $LOCAL_USER;
DROP USER $REMOTE_USER;
EOF

#-- create the db to be used
mysql -u $MYSQL_ADMIN -p$MYSQL_PASS <<EOF
CREATE DATABASE $KEYSTONE_DB;
CREATE USER $LOCAL_USER IDENTIFIED BY $PASS;
GRANT ALL PRIVILEGES on ${KEYSTONE_DB}.* TO $LOCAL_USER WITH GRANT OPTION;
CREATE USER $REMOTE_USER IDENTIFIED BY $PASS;
GRANT ALL PRIVILEGES on ${KEYSTONE_DB}.* TO $REMOTE_USER IDENTIFIED BY $PASS;
FLUSH PRIVILEGES;
EOF

#-- install keystone
sudo apt-get install -y keystone curl python-mysqldb python-dateutil
sudo sed -i "s|connection.*|connection = mysql://${KEYSTONE_DB_USER}:${KEYSTONE_DB_PASS}@127.0.0.1/keystone|g" /etc/keystone/keystone.conf

#-- update the admin token
echo "# DO NOT EDIT: generated by $0" > $KEYVARS
echo "# $(date)" >> $KEYVARS
echo >> $KEYVARS
echo export OS_USERNAME=admin >> $KEYVARS
echo export OS_PASSWORD=$DEFAULT_USER_PASSWORD >> $KEYVARS
echo >> $KEYVARS
KEYSTONE_ADMIN_TOKEN=$(apg -a 0 -m 15 -M NCL -n 1 -c /dev/urandom)
echo export KEYSTONE_ADMIN_TOKEN=\"$KEYSTONE_ADMIN_TOKEN\" >> $KEYVARS
sudo sed -i "s|admin_token.*=.*|admin_token = $KEYSTONE_ADMIN_TOKEN|g" /etc/keystone/keystone.conf
sudo chown keystone:root /etc/keystone/keystone.conf
sudo chmod 0640 /etc/keystone/keystone.conf

#-- set up the remaining keystone environment variables
echo export KEYSTONE_SERVICE_ENDPOINT="http://$KEYSTONE_IP:35357/v2.0/" >> $KEYVARS
echo export KEYSTONE_SERVICE_TOKEN="$KEYSTONE_ADMIN_TOKEN" >> $KEYVARS
echo export KEYSTONE_REGION="demo" >> $KEYVARS
echo >> $KEYVARS
echo export SERVICE_ENDPOINT="http://$KEYSTONE_IP:35357/v2.0/" >> $KEYVARS
echo export SERVICE_TOKEN=$KEYSTONE_ADMIN_TOKEN >> $KEYVARS
echo export REGION=$KEYSTONE_REGION >> $KEYVARS

#-- seed the database
sudo keystone-manage db_sync

#-- restart and verify we can get results (even if it is an empty list)
set +x
sudo service keystone restart
echo
echo -----------------------------------------------------------
echo Run the following commands:
echo
echo    \$ . ./$KEYVARS
echo    \$ keystone user-list
echo
echo You should get output that looks like this:
echo
echo    +----+---------+-------+------+
echo    \| id \| enabled \| email \| name \|
echo    +----+---------+-------+------+
echo    +----+---------+-------+------+
echo
echo If you do, we have succeeded so far.  If not, something is
echo wrong with the keystone configuration.
echo -----------------------------------------------------------
