#!/bin/sh
#
#	initial set up for keystone
#
#

set -e
#set -x

. ./envvars.sh

USERVARS=users_envvars.sh
echo "# DO NOT EDIT: generated by $0" > $USERVARS
echo "# $(date)" >> $USERVARS

#-- set up default tenant and service tenant
TENANT=$(keystone tenant-create --name $DEFAULT_TENANT_NAME | grep id | awk '{print $4}')
SERVICE_TENANT=$(keystone tenant-create --name service --description "Service Tenant" | grep id | awk '{print $4}')
echo export DEFAULT_TENANT_ID=$TENANT >> $USERVARS
echo export SERVICE_TENANT_ID=$SERVICE_TENANT >> $USERVARS

#-- create user roles
ADMIN_ROLE=$(keystone role-create --name Admin | grep id | awk '{print $4}')
KEYSTONE_ADMIN_ROLE=$(keystone role-create --name KeystoneServiceAdmin | grep id | awk '{print $4}')
MEMBER_ROLE=$(keystone role-create --name Member | grep id | awk '{print $4}')
echo export ADMIN_ROLE_ID=$ADMIN_ROLE >> $USERVARS
echo export KEYSTONE_ADMIN_ROLE_ID=$KEYSTONE_ADMIN_ROLE >> $USERVARS
echo export MEMBER_ROLE_ID=$MEMBER_ROLE >> $USERVARS

#-- create users
PASSWORD=$DEFAULT_USER_PASSWORD
keystone user-create --name admin --tenant_id $TENANT --pass $PASSWORD --email root@localhost --enabled true
keystone user-create --name $DEFAULT_USER_NAME --tenant_id $TENANT --pass $PASSWORD --email ${DEFAULT_USER_NAME}@localhost --enabled true

ADMIN_USER=$(keystone user-list | grep admin | awk '{print $2}')
DEFAULT_USER=$(keystone user-list | grep $DEFAULT_USER_NAME | awk '{print $2}')
echo export ADMIN_USER_ID=$ADMIN_USER >> $USERVARS
echo export DEFAULT_USER_ID=$DEFAULT_USER >> $USERVARS

#-- add the Admin user to all of the roles
for ROLE in Admin KeystoneServiceAdmin Member
do
	ROLE_ID=$(keystone role-list | grep "\ $ROLE\ " | awk '{print $2}')
	keystone user-role-add --user $ADMIN_USER --role $ROLE_ID --tenant_id $TENANT
done

#-- add the default user to the Admin and Member roles
for ROLE in Admin Member
do
	ROLE_ID=$(keystone role-list | grep "\ $ROLE\ " | awk '{print $2}')
	keystone user-role-add --user $DEFAULT_USER --role $ROLE_ID --tenant_id $TENANT
done

#-- create service users for each endpoint and grant Admin roles to them
for SERVICE in glance nova swift keystone
do
	keystone user-create --name $SERVICE --pass $SERVICE --tenant_id $SERVICE_TENANT --email ${SERVICE}@localhost --enabled true
	SERVICE_ID=$(keystone user-list | grep "\ $SERVICE\ " | awk '{print $2}')
	keystone user-role-add --user $SERVICE_ID --role $ADMIN_ROLE --tenant_id $SERVICE_TENANT
done

#-- write a short script of curl tests
CURLTEST=curl_test.sh
echo "#!/bin/sh" > $CURLTEST
echo "# DO NOT EDIT: generated by $0" >> $CURLTEST
echo "# $(date)" >> $CURLTEST
echo >> $CURLTEST

echo "#-- see if the API is functional" >> $CURLTEST
echo "curl http://localhost:5000/v2.0/ | python -mjson.tool" >> $CURLTEST
echo "curl http://localhost:35357/v2.0/ | python -mjson.tool" >> $CURLTEST
echo >> $CURLTEST

echo "#-- if those worked, let's try to get user tokens" >> $CURLTEST
echo "curl -d '{\"auth\":{\"passwordCredentials\":{\"username\":\"admin\",\"password\":\"${PASSWORD}\"}}}' -H \"Content-type: application/json\" http://localhost:35357/v2.0/tokens | python -mjson.tool" >> $CURLTEST
echo "curl -d '{\"auth\":{\"passwordCredentials\":{\"username\":\"$DEFAULT_USER_NAME\",\"password\":\"${PASSWORD}\"}}}' -H \"Content-type: application/json\" http://localhost:35357/v2.0/tokens | python -mjson.tool" >> $CURLTEST
chmod +x $CURLTEST

#-- tell them to execute and examine the results
echo "----------------------------------------------------------"
echo "Please run the curl test script and make sure the results"
echo "look okay:"
echo
echo "   $ ./$CURLTEST"
echo "----------------------------------------------------------"

