#!/bin/sh
#
#	initial set up for glance
#
#

set -e
#set -x

. ./envvars.sh

GLANCEVARS=glance_envvars.sh
LOCAL_USER="'$GLANCE_DB_USER'@'localhost'"
REMOTE_USER="'$GLANCE_DB_USER'@'%'"
PASS="'$GLANCE_DB_PASS'"

#-- kill the old glance DB
mysql -f -u $MYSQL_ADMIN -p$MYSQL_PASS <<EOF
DROP DATABASE $GLANCE_DB;
DROP USER $LOCAL_USER;
DROP USER $REMOTE_USER;
EOF

#-- create the db to be used
mysql -u $MYSQL_ADMIN -p$MYSQL_PASS <<EOF
CREATE DATABASE $GLANCE_DB;
CREATE USER $LOCAL_USER IDENTIFIED BY $PASS;
GRANT ALL PRIVILEGES on ${GLANCE_DB}.* TO $LOCAL_USER WITH GRANT OPTION;
CREATE USER $REMOTE_USER IDENTIFIED BY $PASS;
GRANT ALL PRIVILEGES on ${GLANCE_DB}.* TO $REMOTE_USER IDENTIFIED BY $PASS;
FLUSH PRIVILEGES;
EOF

#-- install glance
sudo apt-get install -y glance
sudo sed -i "s|sql_connection.*|sql_connection = mysql://${GLANCE_DB_USER}:${GLANCE_DB_PASS}@127.0.0.1/glance|g" /etc/glance/glance-registry.conf

#-- reconfigure glance to talk to keystone
echo "[paste_deploy]" | sudo tee -a /etc/glance/glance-registry.conf
echo "flavor = keystone" | sudo tee -a /etc/glance/glance-registry.conf

echo "[paste_deploy]" | sudo tee -a /etc/glance/glance-api.conf
echo "flavor = keystone" | sudo tee -a /etc/glance/glance-api.conf

#-- add the correct credentials to the glance-service-paste.ini files
sudo sed -i 's|auth_uri=.*|auth_uri=http://127.0.0.1:5000/|g' /etc/glance/glance-api-paste.ini
sudo sed -i 's|admin_tenant_name=.*|admin_tenant_name=service|g' /etc/glance/glance-api-paste.ini
sudo sed -i 's|admin_user=.*|admin_user=glance|g' /etc/glance/glance-api-paste.ini
sudo sed -i 's|admin_password=.*|admin_password=glance|g' /etc/glance/glance-api-paste.ini

sudo sed -i 's|auth_uri=.*|auth_uri=http://127.0.0.1:5000/|g' /etc/glance/glance-registry-paste.ini
sudo sed -i 's|admin_tenant_name=.*|admin_tenant_name=service|g' /etc/glance/glance-registry-paste.ini
sudo sed -i 's|admin_user=.*|admin_user=glance|g' /etc/glance/glance-registry-paste.ini
sudo sed -i 's|admin_password=.*|admin_password=glance|g' /etc/glance/glance-registry-paste.ini

#-- restart glance
for ii in glance-api glance-registry
do
	sudo service $ii restart
done

#-- check the logs for db table creation
echo "Check the /var/log/glance/*.log files for data base table creation"

#-- set up the remaining keystone environment variables
echo "# DO NOT EDIT: generated by $0" > $GLANCEVARS
echo "# $(date)" >> $GLANCEVARS
echo export OS_AUTH_URL="http://$KEYSTONE_IP:5000/v2.0" >> $GLANCEVARS
echo export OS_AUTH_USER="$DEFAULT_USER_NAME" >> $GLANCEVARS
echo export OS_AUTH_KEY="$DEFAULT_USER_PASSWORD" >> $GLANCEVARS
echo export OS_AUTH_TENANT="$DEFAULT_TENANT_NAME" >> $GLANCEVARS

