#!/bin/sh
#
#	initial set up for nova on cloud controller
#
#

set -e
#set -x

. ./envvars.sh

#-- install nova (cloud controller style)
sudo apt-get install -y nova-api nova-cert nova-common nova-compute \
   nova-compute-kvm nova-doc nova-network nova-objectstore nova-scheduler \
   nova-vncproxy nova-volume python-nova python-novaclient python-keystone

#-- set up the config file for nova
cat <<EOF | sudo tee /etc/nova/nova.conf
--dhcpbridge_flagfile=/etc/nova/nova.conf
--dhcpbridge=/usr/bin/nova-dhcpbridge
--logdir=/var/log/nova
--state_path=/var/lib/nova
--lock_path=/var/lock/nova
--allow_admin_api=true
--use_deprecated_auth=false
--auth_strategy=keystone
--scheduler_driver=nova.scheduler.simple.SimpleScheduler

# same host as the cloud controller
--s3_host=$NOVA_IP
--ec2_host=$EC2_IP
--rabbit_host=$NOVA_IP
--cc_host=$NOVA_IP

# host running nova api
--nova_url=http://$NOVA_IP:8774/v1.1/

# nova api/cloud controller
--routing_source_ip=$NOVA_IP

# glance host
--glance_api_servers=$GLANCE_IP:9292
--image_service=nova.image.glance.GlanceImageService

--iscsi_ip_prefix=$IP_PREFIX
--sql_connection=mysql://$NOVA_DB_USER:$NOVA_DB_PASS@$MYSQL_IP/nova

# host running nova api
--ec2_url=http://$NOVA_IP:8773/services/Cloud

# host running keystone
--keystone_ec2_url=http://$KEYSTONE_IP:5000/v2.0/ec2tokens
--api_paste_config=/etc/nova/api-paste.ini
--libvirt_type=$NOVA_LIBVIRT_TYPE
--libvirt_use_virtio_for_bridges=true
--start_guests_on_host_boot=true
--resume_guests_state_on_host_boot=true
--vnc_enabled=true

# keystone host
--vncproxy_url=http://$KEYSTONE_IP:6080

# network specific settings
--network_manager=nova.network.manager.FlatDHCPManager
--public_interface=eth0
--flat_interface=eth0
--flat_network_bridge=br100

# IP range VMs will get
--fixed_range=$FIXED_RANGE

# what nova uses for the public IP range?
--floating_range=$FLOATING_RANGE
--network_size=$NETWORK_SIZE
--flat_network_dhcp_start=$DHCP_START
--flat_injected=False
--force_dhcp_release

--iscsi_helper=tgtadm
--connection_type=libvirt
--root_helper=sudo nova-rootwrap
--verbose
EOF

#-- add the correct credentials to the api-paste.ini file
sudo sed -i 's|auth_uri.*=.*|auth_uri = http://127.0.0.1:5000/|g' /etc/nova/api-paste.ini
sudo sed -i 's|admin_tenant_name.*=.*|admin_tenant_name = service|g' /etc/nova/api-paste.ini
sudo sed -i 's|admin_user.*=.*|admin_user = nova|g' /etc/nova/api-paste.ini
sudo sed -i 's|admin_password.*=.*|admin_password = nova|g' /etc/nova/api-paste.ini

#-- bring up the nova db
echo sudo nova-manage db sync
sudo nova-manage db sync

#-- set up the private network
sudo nova-manage network create private --fixed_range_v4=$FIXED_RANGE --num_networks=1 --bridge=br100 --bridge_interface=eth0 --network_size=64

#-- make sure file ownerships are correct
sudo chown -R nova:nova /etc/nova

#-- restart nova
SVCS="libvirt-bin nova-network nova-compute nova-api nova-objectstore \
   nova-scheduler nova-volume nova-vncproxy nova-cert"
for ii in $SVCS
do
	sudo service $ii restart
done

