#!/bin/sh
#
#	initial set up for getting nova credentials
#
# NB: requires the previously created eucarc, keystone_envvars.sh
#

set -e
set -x

. ./envvars.sh

#-- set up some environment variables for later use
# KEYSTONE_IP is already defined
export NOVA_API_SERVER=$NOVA_IP
# SERVICE_ENDPOINT is already defined
# SERVICE_TOKEN is already defined
export ACCESS_KEY=$EC2_ACCESS_KEY
export SECRET_KEY=$EC2_SECRET_KEY

#-- start stashing things in an rc file
if [ ! -d ~/creds ]
then
	mkdir ~/creds
fi
CREDS=~/creds/openrc
echo "# DO NOT EDIT: generated by $0" > $CREDS
echo "# $(date)" >> $CREDS
echo >> $CREDS

echo export KEYSTONE_IP=$KEYSTONE_IP >> $CREDS
echo export NOVA_API_SERVER=$NOVA_IP >> $CREDS
echo export GLANCE_API_SERVER=$NOVA_IP >> $CREDS
echo export SERVICE_ENDPOINT=$SERVICE_ENDPOINT >> $CREDS
echo export SERVICE_TOKEN=$SERVICE_TOKEN >> $CREDS
echo export ACCESS_KEY=$EC2_ACCESS_KEY >> $CREDS
echo export SECRET_KEY=$EC2_SECRET_KEY >> $CREDS

#-- now build up the crucial part of the creds
cat <<EOF | tee -a $CREDS

export NOVA_KEY_DIR="$NOVA_KEY_DIR"

# OS API settings
export NOVA_USERNAME="$DEFAULT_USER_NAME"
export NOVA_PROJECT_ID="$DEFAULT_PROJECT_NAME"
export NOVA_PASSWORD="$DEFAULT_USER_PASSWORD"
export NOVA_API_KEY=\${NOVA_PASSWORD}
export NOVA_URL=http://\$KEYSTONE_IP:35357/v2.0/
export NOVA_VERSION="1.1"
export NOVA_REGION_NAME="$KEYSTONE_REGION"

export OS_AUTH_USER=\${NOVA_USERNAME}
export OS_AUTH_KEY=\${NOVA_PASSWORD}
export OS_AUTH_TENANT=\${NOVA_PROJECT_ID}
export OS_AUTH_URL=\${NOVA_URL}
export OS_AUTH_STRATEGY="keystone"

# EC2 API settings (ACCESS_KEY and SECRET_KEY were generated during
# Keystone configuration)
export EC2_URL="http://\$NOVA_API_SERVER:8773/services/Cloud"
export EC2_ACCESS_KEY=\$ACCESS_KEY
export EC2_SECRET_KEY=\$SECRET_KEY
export S3_URL="http://\$GLANCE_API_SERVER:3333"
export EC2_USER_ID=42 # nova does not use user id, but bundling requires it
export EC2_PRIVATE_KEY=\${NOVA_KEY_DIR}/pk.pem
export EC2_CERT=\${NOVA_KEY_DIR}/cert.pem
export NOVA_CERT=\${NOVA_KEY_DIR}/cacert.pem
export EUCALYPTUS_CERT=\${NOVA_CERT} # euca-bundle-image requires this set
alias ec2-bundle-image="ec2-bundle-image --cert \${EC2_CERT} --privatekey \${EC2_PRIVATE_KEY} --user 42 --ec2cert \${NOVA_CERT}"
alias ec2-upload-bundle="ec2-upload-bundle -a \${EC2_ACCESS_KEY} -s \${EC2_SECRET_KEY} --url \${S3_URL} --ec2cert \${NOVA_CERT}"
EOF

