
import bmark
import bmark.parser
import os
import os.path
import sys

class BmarkDirectory(bmark.DataCollection):

    def __init__(self, rootdir):
        '''connect to the collection of benchmark data'''
	if not os.path.exists(rootdir):
	    os.makedirs(rootdir)
	self.rootdir = rootdir
	bmark.parser.register_all(os.getcwd())
	return

    def get_benchmarks(self):
	'''return a list of benchmarks we know about in this data
	   collection'''
	for root, dirs, files in os.walk(self.rootdir):
	    if root == self.rootdir:
		result = []
		result += dirs
	        return result
	return None

    def entry_exists(self, bmark, entry):
	'''does an entry exist with the given name? return a True
	   or False'''
	return os.path.exists(os.path.join(self.rootdir, bmark, entry))

    def get_entry_list(self, bmark):
	'''return a list of entries we know about for this benchmark'''
	for root, dirs, files in os.walk(os.path.join(self.rootdir, bmark)):
	    if root == os.path.join(self.rootdir, bmark):
		result = []
		result += dirs
	        return result
	return None

    def add_entry(self, bmark, entry):
	'''if the entry of the given name does not exist, create it.
	   return True when successful.'''
        result = False
	if not self.entry_exists(bmark, entry):
	    os.makedirs(os.path.join(self.rootdir, bmark, entry))
	    result = True
	return result

    def delete_entry(self, bmark, entry):
	'''if the entry of the given name exists, remove it from
	   the collection'''
	os.removedirs(os.path.join(self.rootdir, bmark, entry))
	return

    #-- methods to handle blobs associated with each entry
    def entry_blob_exists(self, bmark, entry, blob_name):
	'''see if a blob is already there or not'''
	path = os.path.join(self.rootdir, bmark, entry, blob_name)
	return os.path.exists(path)

    def get_entry_blobs_list(self, bmark, entry):
	'''return a list of known data blobs'''
	path = os.path.join(self.rootdir, bmark, entry)
	for root, dirs, files in os.walk(path):
	    if root == path:
		result = []
		result += files
	        return result
	return None

    def get_entry_blob(self, bmark, entry, blob_name):
	'''return a specific data blob'''
	path = os.path.join(self.rootdir, bmark, entry, blob_name)
	fd = open(path, 'r+')
	blob = fd.readlines()
	fd.close()
	return blob

    def add_entry_blob(self, bmark, entry, blob_name, blob):
	'''add a data blob to an entry'''
	path = os.path.join(self.rootdir, bmark, entry, blob_name)
	fd = open(path, 'w+')
	fd.writelines(blob)
	fd.close()
	return

    def delete_entry_blob(self, bmark, entry, blob_name):
	'''if the blob for the entry of the given name exists, remove it
	   from the entry'''
	path = os.path.join(self.rootdir, bmark, entry, blob_name)
	if os.path.exists(path):
	    os.remove(path)
	return

