
import bmark
import importlib
import os
import os.path
import string

known_parsers = {}

def register_all(rootdir):
    '''find all the known parsers, import them and then have them register
       so we know they are there'''
    for root, dirs, files in os.walk(os.path.join(rootdir, 'bmark', 'parser')):
       for ii in files:
           if ii[0] not in string.uppercase or ii[len(ii)-4:] == '.pyc':
	      continue
	   modname = ii[0:len(ii)-3]
	   fullmod = '.'.join(['bmark', 'parser', modname])
	   known_parsers[modname] = importlib.import_module(fullmod)
    return

def get_dataset_class(bmark_parser):
    cls = None
    if bmark_parser in known_parsers:
        cls = eval('known_parsers[bmark_parser].%s()' % bmark_parser)
    return cls


class Parser:

    def __init__(self):
        self.bmc = None		# benchmark collection to get/set data in
	self.dataset = {}	# what will get written to disk eventually
        self.duration = None	# total length of time for the job (NOT the
				#     benchmark)
        self.report_url = None	# where the Jenkins report can be found
        self.timestamp = None	# when the benchmark job was run
	return

    def __str__(self):
	data = ''
	klist = self.dataset.keys()
	klist.sort()
	for ii in klist:
	    data += '%s: %s\n' % (ii, self.dataset[ii])
	return data

    def get_bmc(self):
	return self.bmc

    def set_bmc(self, bmc):
	self.bmc = bmc
	return

    def get_duration(self):
	return self.dataset['Job-Duration']

    def set_duration(self, duration):
	self.dataset['Job-Duration'] = duration
	return

    def get_bmark_name(self):
	return self.dataset['Benchmark-Name']

    def set_bmark_name(self, bmark_name):
	self.dataset['Benchmark-Name'] = bmark_name
	return

    def get_report_url(self):
	return self.dataset['Report-URL']

    def set_report_url(self, report_url):
	self.dataset['Report-URL'] = report_url
	return

    def get_timestamp(self):
	return self.dataset['Job-Timestamp']

    def set_timestamp(self, timestamp):
	self.dataset['Job-Timestamp'] = timestamp
	return

    def set_common_values(self, log):
        '''given the output console log, glean whatever we need to
           from it that is the same for all benchmarks (e.g., output
	   from runner.py'''
	common = { 'RUNNER_BMARK_START' : 'Benchmark-Start',
                   'RUNNER_BMARK_STOP' : 'Benchmark-Stop',
                   'RUNNER_HOST_ARCH' : 'Host-Arch',
                   'RUNNER_HOST_CPU' : 'Host-CPU',
                   'RUNNER_HOST_CPU_COUNT' : 'Host-CPU-Count',
                   'RUNNER_HOST_NAME' : 'Host-Name',
                   'RUNNER_HOST_IP' : 'Host-IP',
                   'RUNNER_HOST_RAM' : 'Host-RAM',
                   'RUNNER_HOST_UNAME' : 'Host-Uname-Output',
                   'RUNNER_KEYWORDS' : 'Keywords',
                   'RUNNER_TAGS' : 'Tags',
                 }
        lines = log.split('\n')
	for ii in lines:
            ii.strip()
	    data = ii.split(':')
	    if len(data) > 1:
	        s = data[0].strip()
                if s in common:
                    d = ':'.join(data[1:])
	            self.dataset[common[s]] = d.strip()
	return

    def parse_log(self, log):
        '''given the output console log, glean whatever we need to
           from it that is specific to the benchmark'''
	# by default, we do nothing
	return

