#!/usr/bin/python

import argparse
import bmark
import bmark.BmarkDirectory
import bmark.Dataset
import bmark.HtmlPage
import bmark.parser
import HTMLParser
import os
import os.path
import stat
import string
import subprocess
import sys
import time


def main():
    #-- figure out the command line parameters
    home = os.getenv('HOME') or '/var/lib/jenkins'
    parser = argparse.ArgumentParser()
    parser.add_argument('--results', default='./results',
                        help='directory containing benchmark results')
    parser.add_argument('--html', default='./html',
                        help='directory containing HTML output')
    parser.add_argument('--bmark', help='benchmark name', required=True)
    args = parser.parse_args()

    if not args.bmark:
        parser.print_help()

    #-- connect to the benchmark data collection
    bmd = bmark.BmarkDirectory.BmarkDirectory(args.results)

    #-- sort through all of the available data
    bmarks = bmd.get_benchmarks()
    if args.bmark in bmarks:
	x = []
	y_duration = []
	y_duration_label = 'Total Job Duration (secs)'

	y_benchmark = []
	y_benchmark_label = 'Total Benchmark Duration (secs)'

	for ii in bmd.get_entry_list(args.bmark):
	    dsraw = bmd.get_entry_blob(args.bmark, ii, 'dataset')
	    ds = bmark.Dataset.Dataset(dsraw)

	    when = int(ds.get_value('Job-Timestamp'))
	    x.append(when)
	    y = int(ds.get_value('Job-Duration'))/1000
	    y_duration.append(y)

	    start = ds.get_value('Benchmark-Start')
	    stop = ds.get_value('Benchmark-Stop')
	    if start and stop:
	        y = int(stop) - int(start)
	    else:
		y = 0
	    y_benchmark.append(y)
	    
	title = 'Benchmark/Workload Duration for %s' % args.bmark
	p = bmark.HtmlPage.HtmlPage(args.bmark, args.html, title)
	# build a row ordered list of lists -- each row is x, y1, y2, ...
	td = []
	for ii in range(0, len(x)):
	   dt = time.asctime(time.gmtime(x[ii]/1000))
	   td.append([ii, dt, x[ii], y_duration[ii], y_benchmark[ii]])
	p.add_table(td,
		    'Duration Data',
		    ['Sample',
		     'Date and Time (UTC)',
		     'Timestamp',
		     'Jenkins Job Duration (secs)',
		     'Benchmark/Workload Duration (secs)'
		    ]
		   )
	p.add_graph('%s Benchmark/Workload Durations' % args.bmark)
	p.add_graph_labels('Sample', 'Seconds')
	p.add_graph_curve(range(0, len(x)), y_duration, 'Jenkins Job')
	p.add_graph_curve(range(0, len(x)), y_benchmark, 'Benchmark/Workload')
	p.write_graph('%s-duration.png' % args.bmark)
        p.write()

    else:
        print 'E: no data for benchmark "%s"' % args.bmark

if __name__ == '__main__':
    main()

