
import argparse
import os
import os.path
import subprocess
import sys
import tempfile
import yaml

import hwpool


class PandaKit(hwpool.HardwarePool):

    def get_available_machines(self, tags):
        command = ['pk', 'list']
        command.extend(tags)
        p = subprocess.Popen(command, stdout=subprocess.PIPE)
        return p.communicate()[0].split()

    def instantiate_machines(self, machines, keywords):
        tasks = {}
        for machine in machines:
            task = tasks[machine] = {}
            task['name'] = machine
            log = task['log_file'] = tempfile.NamedTemporaryFile(delete=False)
            command = ['pk', 'install', '--tries=8', machine]
            if keywords:
                command.extend(keywords)
            task['process'] = subprocess.Popen(command, stdout=log, stderr=log)
        for task in tasks.itervalues():
            exit_status = task['process'].wait()
            if exit_status:
                raise RuntimeError(
                    'Machine %s could not be provisioned; log in %s' %
                    (task['name'], task['log_file'].name))
            os.unlink(task['log_file'].name)
            task['log_file'].close()


hwpool.hwpool = PandaKit
