#
#	Commonly used helper functions
#
WLTM_DEBUG=${WLTM_DEBUG:=false}

wltm_timestamp() {
   echo $(date -u)
}

wltm_debug_msg() {
   if [ "$WLTM_DEBUG" = "true" ]; then
      echo "DEBUG $(wltm_timestamp): $@" >> /tmp/wltm_debug.log
   fi
}

wltm_begin_test() {
   wltm_debug_msg "WLTM_BEGIN_TEST: $@ ["$(wltm_timestamp)"]"
   echo "WLTM_BEGIN_TEST: $@ ["$(wltm_timestamp)"]"
}

wltm_end_test() {
   wltm_debug_msg "WLTM_END_TEST: $@ ["$(wltm_timestamp)"]"
   echo "WLTM_END_TEST: $@ ["$(wltm_timestamp)"]"
}

wltm_test_pass() {
   wltm_debug_msg "PASS: $@ ["$(wltm_timestamp)"]"
   echo "PASS: $@ ["$(wltm_timestamp)"]"
}

wltm_test_fail() {
   wltm_debug_msg "FAIL: $@ ["$(wltm_timestamp)"]"
   echo "FAIL: $@ ["$(wltm_timestamp)"]"
}

wltm_mark() {
   wltm_debug_msg "MARK: $@ ["$(wltm_timestamp)"]"
   echo "MARK: $@ ["$(wltm_timestamp)"]"
}

wltm_package_install() {
   wltm_debug_msg "WLTM_PACKAGE_INSTALL sudo apt-get -y install $@"
   sudo apt-get -y install $@
}

wltm_package_purge() {
   wltm_debug_msg "WLTM_PACKAGE_PURGE sudo apt-get -y purge $@"
   sudo apt-get -y purge $@
}

wltm_remote_package_install() {
   where=$1
   shift
   wltm_debug_msg "WLTM_REMOTE_PACKAGE_INSTALL ssh root@$where apt-get -y install $@"
   ssh root@$where "apt-get -y install $@"
}

wltm_remote_package_purge() {
   where=$1
   shift
   wltm_debug_msg "WLTM_REMOTE_PACKAGE_PURGE ssh root@$where apt-get -y purge $@"
   ssh root@$where "apt-get -y purge $@"
}

wltm_remote_exec() {
   where=$1
   shift
   wltm_debug_msg "WLTM_REMOTE_EXEC ssh root@$where $@"
   ssh root@$where "$@"
}

