#!/usr/bin/env python
#

import ConfigParser
import socket
import sys
import os
import os.path
import daemon
import daemon.runner

SERVER   = 'server'
MACHINES = 'machines'

def get_config(opts):
   config = {}

   def home_path():
      return os.getenv('HOME')
   def default_server():
      return 'localhost:21003'
   def default_machines():
      return ['localhost']

   cfg = ConfigParser.ConfigParser()
   confbase = 'machines.conf'
   conffile = ''
   if os.path.exists(confbase):
      conffile = confbase
   elif os.path.exists(os.path.join(home_path(), confbase)):
      conffile = os.path.join(home_path(), confbase)
   else:
      print 'E: cannot find a machines.conf file'
      sys.exit(1)
   cfg.read(conffile)

   if cfg.has_section(MACHINES) == False:
      print 'E: unsupported machine configuration file format'
      sys.exit(1)

   for opt in opts:
      try:
         if opt in MACHINES:
            config[opt] = cfg.get(MACHINES, opt).split()
         else:
            config[opt] = cfg.get(MACHINES, opt)
      except ConfigParser.NoOptionError:
         config[opt] = locals()['default_%s' % opt]()

   return config

def main():
   retval = 0
   opts = [SERVER, MACHINES]
   config = get_config(opts)
   
   server = config[SERVER]
   where = server.split(':')
   server = where[0]
   port   = where[1]
   backlog = 5
   info = socket.getaddrinfo(server, port, 0, 0, socket.SOL_UDP)
   sockaddr = info[0][4]
   sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
   sock.bind(sockaddr)
   sock.listen(backlog)

   mlist = {}
   for ii in config[MACHINES]:
      mlist[ii] = 0

   while True:
      client, addr = sock.accept()
      data = client.recv(1024)
      print 'I: received ->', data, 'from', addr
      if data == 'GET':
         idx, val = min(mlist.iteritems(), key=lambda x: x[1])
	 if idx:
            data = idx
            mlist[idx] += 1
         else:
            val = -1
            data = 'NAK'
         print 'I: sent ->', data, 'to', addr, '(count = %d)' % (mlist[idx])
         client.send(data)
         client.close()
      elif data[0:3] == 'PUT':
         name = data[3:].strip()
         mlist[name] -= 1
         if mlist[name] < 0:
            mlist[name] = 0
         data = 'ACK'
         print 'I: sent ->', data, 'to', addr
         client.send(data)
         client.close()
      else:
         print 'E: invalid command "%s" from %s' % (data, addr)

   return retval

retval = 0
if __name__ == '__main__':
   retval = main()

sys.exit(retval)
